<?php
# Adding jobs for current group.
#
# Copyright (C) 1999, 2000 The SourceForge Crew
# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
# Copyright (C) 2014, 2016, 2017 Assaf Gordon
# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
# Copyright (C) 2013, 2014, 2017-2024 Ineiev
#
# This file is part of Savane.
#
# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
# under the terms of the GNU General Public license version 3 or (at your
# option) any later version; further contributions are covered by
# the GNU Affero General Public license version 3 or (at your option)
# any later version.  The license notices for the AGPL and the GPL follow.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

require_once ('../include/init.php');
require_once ('../include/people/general.php');

if (!$group_id)
  exit_no_group ();
if (!user_ismember ($group_id, 'A'))
  exit_permission_denied ();

# Fill in the info to create a job.
site_project_header (
  [ 'title' => _("Create a job for your project"),
    'group' => $group_id,'context' => 'ahome']
);

utils_get_content ("people/createjob");

print form_tag (['action' => $GLOBALS['sys_home'] . 'people/editjob.php'])
  . form_hidden (['group_id' => $group_id])
  . '<b>' . _("Category:") . "</b><br />\n"
  .  people_job_category_box ('category_id')
  . "\n<p><b>" . html_label ('title', _("Summary:"))
  . "</b><br />\n"
  . form_input ('text', 'title', '', 'size="40" maxlength="60"')
  . "</p>\n<p>"
  . _("Your group description will be inserted on the announce.")
  . "</p>\n<p>"
  . html_label ('description', _("Details (job description, contact...):"))
  . "</b><br />\n"
  . form_textarea ('description', '', 'rows="10" cols="60" wrap="soft"')
  . "</p>\n<p>"
  . form_submit (_("continue >>"), "add_job") . "\n</p>\n</form>\n";
site_project_footer ([]);
?>
